"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.plaform500response = exports.plaform404response = void 0;
/* eslint-disable jest/no-conditional-expect */
const nock_1 = __importDefault(require("nock"));
const LensPlatformClient_1 = __importDefault(require("./LensPlatformClient"));
const LensPlatformClient_test_1 = require("./LensPlatformClient.test");
const exceptions_1 = require("./exceptions");
exports.plaform404response = {
    name: "HTTPError",
    message: "Response code 404 (Not Found)",
};
exports.plaform500response = {
    name: "HTTPError",
    message: "Response code 500 (Internal Server Error)",
};
describe(".users.*", () => {
    const invalidUserName = "idonotexist";
    const brokenUserName = "ibreakthings";
    const username = "randomuser";
    const userResponse = { username };
    const lensPlatformClient = new LensPlatformClient_1.default(LensPlatformClient_test_1.minimumOptions);
    beforeAll(() => {
        (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).get(`/users/${invalidUserName}`).reply(404, exports.plaform404response);
        (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress)
            .get(`/users/${brokenUserName}`)
            .reply(500, exports.plaform500response)
            .persist();
        (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).get(`/users/${username}`).reply(200, userResponse);
    });
    it("doesn't break functionality", async () => {
        const result = await lensPlatformClient.user.getOne({ username });
        expect(result).toStrictEqual(userResponse);
    });
    it("throws proper expected exception", async () => {
        const expectedException = new exceptions_1.NotFoundException(`User ${invalidUserName} not found`);
        try {
            await lensPlatformClient.user.getOne({ username: invalidUserName });
        }
        catch (e) {
            // Check exact exception
            expect(e).toStrictEqual(expectedException);
            // Check reflected type
            expect(e).toBeInstanceOf(exceptions_1.NotFoundException);
            expect(e).toBeInstanceOf(exceptions_1.LensSDKException);
        }
    });
    it("throws proper unexpected exception", async () => {
        try {
            await lensPlatformClient.user.getOne({ username: brokenUserName });
        }
        catch (e) {
            expect(e).toBeInstanceOf(exceptions_1.LensSDKException);
            if (e instanceof exceptions_1.LensSDKException) {
                expect(e.errorCode).toEqual(500);
                expect(e.message).toMatch(/Unexpected exception \[Lens Platform SDK\]/);
            }
        }
    });
});
