import type { Except } from "type-fest";
import { Base } from "./Base";
import type { Space, SpaceEntity } from "./SpaceService";
import type { MapToEntity } from "./types/types";
import type { User } from "./UserService";
export declare const teamEntityKinds: readonly ["Admin", "Normal", "Owner"];
export type TeamEntityKind = typeof teamEntityKinds[number];
/**
 *
 * @remarks
 * This interface should be generated using OpenAPI generator in the future.
 *
 * @alpha
 */
export interface Team {
    id?: string;
    name: string;
    description: string;
    kind?: TeamEntityKind;
    createdById?: string;
    users?: User[];
    spaceId: string;
    space?: Space;
    createdAt?: string;
    updatedAt?: string;
}
export type TeamEntity = Except<MapToEntity<Team>, "space"> & {
    space?: SpaceEntity;
};
/**
 *
 * The class for consuming all `team` resources.
 *
 * @remarks
 * This class should be generated using OpenAPI generator in the future.
 *
 * @alpha
 */
declare class TeamService extends Base {
    /**
     * Get one team by team id
     */
    getOne({ id }: {
        id: string;
    }): Promise<Team>;
    /**
     * Get all teams
     */
    getMany(): Promise<Team[]>;
    /**
     * Create one team
     */
    createOne({ team }: {
        team: Team;
    }): Promise<Team>;
    /**
     * Delete one team by team id
     */
    deleteOne({ id }: {
        id: string;
    }): Promise<void>;
    /**
     * Add a user by username to a team by team id
     */
    addUser({ username, id }: {
        username: string;
        id: string;
    }): Promise<Team>;
    /**
     * Remove a user by username from a team by team id
     */
    removeUser({ username, id }: {
        username: string;
        id: string;
    }): Promise<Team>;
}
export { TeamService };
