"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const nock_1 = __importDefault(require("nock"));
const LensPlatformClient_test_1 = require("./LensPlatformClient.test");
const LensPlatformClient_1 = __importDefault(require("./LensPlatformClient"));
const Permissions_1 = require("./Permissions");
describe(".user role.*", () => {
    const username = "test-username";
    const spaceName = "test-space";
    const lensPlatformClient = new LensPlatformClient_1.default(LensPlatformClient_test_1.minimumOptions);
    describe("Change user role", () => {
        it("Should change use role from Member to Admin", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).patch(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Admin",
            });
            const role = await lensPlatformClient.roles.setUserRole(spaceName, username, Permissions_1.Roles.Admin);
            expect(role).toEqual({ role: Permissions_1.Roles.Admin });
        });
        it("Should change use role from Member to Owner", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).patch(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Owner",
            });
            const role = await lensPlatformClient.roles.setUserRole(spaceName, username, Permissions_1.Roles.Owner);
            expect(role).toEqual({ role: Permissions_1.Roles.Owner });
        });
        it("Should change use role from Admin to Member", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).patch(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Normal",
            });
            const role = await lensPlatformClient.roles.setUserRole(spaceName, username, Permissions_1.Roles.Admin);
            expect(role).toEqual({ role: Permissions_1.Roles.Member });
        });
        it("Should change use role from Owner to Member", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).patch(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Normal",
            });
            const role = await lensPlatformClient.roles.setUserRole(spaceName, username, Permissions_1.Roles.Owner);
            expect(role).toEqual({ role: Permissions_1.Roles.Member });
        });
        it("Should change use role from Owner to Admin", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).patch(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Admin",
            });
            const role = await lensPlatformClient.roles.setUserRole(spaceName, username, Permissions_1.Roles.Admin);
            expect(role).toEqual({ role: Permissions_1.Roles.Admin });
        });
    });
    describe("Get use role", () => {
        it("Should get Member use role", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).get(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Normal",
            });
            const role = await lensPlatformClient.roles.getUserSpaceRole(spaceName, username);
            expect(role).toEqual({ role: Permissions_1.Roles.Member });
        });
        it("Should get Admin use role", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).get(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Admin",
            });
            const role = await lensPlatformClient.roles.getUserSpaceRole(spaceName, username);
            expect(role).toEqual({ role: Permissions_1.Roles.Admin });
        });
        it("Should get Owner use role", async () => {
            (0, nock_1.default)(LensPlatformClient_test_1.apiEndpointAddress).get(`/spaces/${spaceName}/users/${username}/role`).reply(200, {
                role: "Owner",
            });
            const role = await lensPlatformClient.roles.getUserSpaceRole(spaceName, username);
            expect(role).toEqual({ role: Permissions_1.Roles.Owner });
        });
    });
});
