"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InvalidEmailDomainException = exports.EmailMissingException = exports.PendingInvitationException = exports.UserAlreadyExistsException = exports.PastExpiryException = void 0;
const common_exceptions_1 = require("./common.exceptions");
class PastExpiryException extends common_exceptions_1.UnprocessableEntityException {
    constructor(msg = "Expiry time can't be in the past") {
        super(msg);
        Object.setPrototypeOf(this, PastExpiryException.prototype);
    }
}
exports.PastExpiryException = PastExpiryException;
class UserAlreadyExistsException extends common_exceptions_1.UnprocessableEntityException {
    constructor(userName) {
        super(`User${userName ? ` ${userName}` : ""} already exists in space`);
        Object.setPrototypeOf(this, UserAlreadyExistsException.prototype);
    }
}
exports.UserAlreadyExistsException = UserAlreadyExistsException;
class PendingInvitationException extends common_exceptions_1.UnprocessableEntityException {
    constructor(userName) {
        super(`User${userName ? ` ${userName}` : ""} already has a pending invitation to this space`);
        Object.setPrototypeOf(this, PendingInvitationException.prototype);
    }
}
exports.PendingInvitationException = PendingInvitationException;
class EmailMissingException extends common_exceptions_1.UnprocessableEntityException {
    constructor() {
        super("Email address is missing from invitation object");
        Object.setPrototypeOf(this, EmailMissingException.prototype);
    }
}
exports.EmailMissingException = EmailMissingException;
class InvalidEmailDomainException extends common_exceptions_1.ForbiddenException {
    // The message is e.g.:
    // "Sorry, your email address domain example.com is not authorized to join this Space.
    // Please contact your Space Administrator."
    constructor(message) {
        super(message);
        Object.setPrototypeOf(this, InvalidEmailDomainException.prototype);
    }
}
exports.InvalidEmailDomainException = InvalidEmailDomainException;
