import { Base } from "./Base";
import { ForbiddenException, SpaceNotFoundException, throwExpected, InternalServerException, } from "./exceptions";
export class BillingPageTokenService extends Base {
    /**
     * Fetches Recurly's billing page token
     * required to access billing information controls.
     * **IMPORTANT**: will fail with 500 when trying to fetch token for free spaces
     * due to a non-existent subscription information
     * @param spaceName - name of the space
     * @returns billing page token
     */
    async getOne(spaceName) {
        const { apiEndpointAddress, fetch } = this.lensPlatformClient;
        const url = `${apiEndpointAddress}/spaces/${spaceName}/billing-page-token`;
        const token = await throwExpected(async () => fetch.get(url), {
            404: () => new SpaceNotFoundException(spaceName),
            403: () => new ForbiddenException("Token can only be acquired by space owners and admins"),
            500: (response) => { var _a, _b; return new InternalServerException((_b = (_a = response === null || response === void 0 ? void 0 : response.body) === null || _a === void 0 ? void 0 : _a.message) !== null && _b !== void 0 ? _b : "Could not retrieve token"); },
        });
        return token;
    }
}
