import { Base } from "./Base";
import { Business } from "./BusinessService";
export interface SSO {
    identityProviderID: string;
}
export interface OIDCRemoteConfiguration {
    authorizationUrl: string;
    tokenUrl: string;
    jwksUrl: string;
    userInfoUrl: string;
    issuer: string;
    logoutUrl: string;
}
export interface SSOProviderConnection {
    link: string;
}
declare class SSOService extends Base {
    /**
     * Get SSO details by business handle
     */
    getSSOByBusinessHandle(handle: Business["handle"]): Promise<SSO>;
    /**
     * Get SSO details by domain
     */
    getSSOByDomain(domain: string): Promise<SSO>;
    /**
     * Get OIDC SSO configuration
     */
    getRemoteOIODCConfiguration(remoteOidcConfigUrl: string): Promise<OIDCRemoteConfiguration>;
    /**
     * Get SSO provider connection link
     */
    getSSOProviderConnectionLink(providerAlias: string, clientId: string): Promise<SSOProviderConnection>;
}
export { SSOService };
